package com.zd.laboratory.service;

import java.util.List;
import com.zd.laboratory.domain.LabProcessSite;

/**
 * 违��-处理方式设置Service接口
 * 
 * @author zd
 * @date 2021-12-13
 */
public interface ILabProcessSiteService 
{
    /**
     * 查询违��-处理方式设置
     * 
     * @param id 违��-处理方式设置主键
     * @return 违��-处理方式设置
     */
    public LabProcessSite selectLabProcessSiteById(Long id);

    /**
     * 查询违��-处理方式设置列表
     * 
     * @param labProcessSite 违��-处理方式设置
     * @return 违��-处理方式设置集合
     */
    public List<LabProcessSite> selectLabProcessSiteList(LabProcessSite labProcessSite);

    /**
     * 新增违��-处理方式设置
     * 
     * @param labProcessSite 违��-处理方式设置
     * @return 结果
     */
    public int insertLabProcessSite(LabProcessSite labProcessSite);

    /**
     * 修改违��-处理方式设置
     * 
     * @param labProcessSite 违��-处理方式设置
     * @return 结果
     */
    public int updateLabProcessSite(LabProcessSite labProcessSite);

    /**
     * 批量删除违��-处理方式设置
     * 
     * @param ids 需要删除的违��-处理方式设置主键集合
     * @return 结果
     */
    public int deleteLabProcessSiteByIds(Long[] ids);

    /**
     * 删除违��-处理方式设置信息
     * 
     * @param id 违��-处理方式设置主键
     * @return 结果
     */
    public int deleteLabProcessSiteById(Long id);
}
